@@ -1,6 +1,6 @@
 package Elasticsearch::Client::Direct;
 {
-  $Elasticsearch::Client::Direct::VERSION = '0.73';
+  $Elasticsearch::Client::Direct::VERSION = '0.74';
 }
 
 use Moo;
@@ -75,7 +75,7 @@ Elasticsearch::Client::Direct - Thin client with full support for Elasticsearch
 
 =head1 VERSION
 
-version 0.73
+version 0.74
 
 =head1 SYNOPSIS
 
@@ -286,7 +286,7 @@ Query string parameters:
     C<version>,
     C<version_type>
 
-See the L<index docs|http://www.elasticsearch.org/guide/reference/api/index_/>
+See the L<index docs|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/docs-index_.html>
 for more information.
 
 =head2 C<create()>
@@ -317,7 +317,7 @@ Query string parameters:
     C<version>,
     C<version_type>
 
-See the L<create docs|http://www.elasticsearch.org/guide/reference/api/create/>
+See the L<create docs|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/docs-create.html>
 for more information.
 
 =head2 C<get()>
@@ -342,7 +342,7 @@ Query string parameters:
     C<refresh>,
     C<routing>
 
-See the L<get docs|http://www.elasticsearch.org/guide/reference/api/get/>
+See the L<get docs|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/docs-get.html>
 for more information.
 
 =head2 C<get_source()>
@@ -367,7 +367,7 @@ Query string parameters:
     C<refresh>,
     C<routing>
 
-See the L<get_source docs|http://www.elasticsearch.org/guide/reference/api/get/>
+See the L<get_source docs|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/docs-get.html>
 for more information.
 
 =head2 C<exists()>
@@ -388,7 +388,7 @@ Query string parameters:
     C<refresh>,
     C<routing>
 
-See the L<exists docs|http://www.elasticsearch.org/guide/reference/api/get/>
+See the L<exists docs|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/docs-get.html>
 for more information.
 
 =head2 C<delete()>
@@ -412,7 +412,7 @@ Query string parameters:
     C<version>,
     C<version_type>
 
-See the L<delete docs|http://www.elasticsearch.org/guide/reference/api/delete/>
+See the L<delete docs|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/docs-delete.html>
 for more information.
 
 =head2 C<update()>
@@ -469,7 +469,7 @@ Query string parameters:
     C<version>,
     C<version_type>
 
-See the L<update docs|http://www.elasticsearch.org/guide/reference/api//>
+See the L<update docs|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/docs-update.html>
 for more information.
 
 =head1 BULK DOCUMENT CRUD METHODS
@@ -554,7 +554,7 @@ Query string parameters:
     C<replication>,
     C<type>
 
-See the L<bulk docs|http://www.elasticsearch.org/guide/reference/api/bulk/>
+See the L<bulk docs|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/docs-bulk.html>
 for more information.
 
 =head2 C<mget()>
@@ -603,7 +603,7 @@ Query string parameters:
     C<realtime>,
     C<refresh>
 
-See the L<mget docs|http://www.elasticsearch.org/guide/reference/api/multi-get/>
+See the L<mget docs|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/docs-multi-get.html>
 for more information.
 
 =head2 C<delete_by_query()>
@@ -642,7 +642,7 @@ Query string parameters:
     C<source>,
     C<timeout>
 
-See the L<delete_by_query docs|http://www.elasticsearch.org/guide/reference/api/delete-by-query/>
+See the L<delete_by_query docs|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/docs-delete-by-query.html>
 for more information.
 
 =head1 SEARCH METHODS
@@ -662,23 +662,23 @@ and of one, more or all types:
 The C<search()> method searches for matching documents in one or more
 indices.  It is just as easy to search a single index as it is to search
 all the indices in your cluster.  It can also return
-L<facets|http://www.elasticsearch.org/guide/reference/api/search/facets/>
+L<facets|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/search-facets.thml>
 (aggregations on particular fields),
-L<highlighted snippets|http://www.elasticsearch.org/guide/reference/api/search/highlighting/>
-and L<did-you-mean|http://www.elasticsearch.org/guide/reference/api/search/phrase-suggest/>
-or L<search-as-you-type|http://www.elasticsearch.org/guide/reference/api/search/completion-suggest.html>
+L<highlighted snippets|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/search-highlighting.html>
+and L<did-you-mean|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/search-suggesters-phrase.html>
+or L<search-as-you-type|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/search-suggesters-completion.html>
 suggestions.
 
-The I<lite> L<version of search|http://www.elasticsearch.org/guide/reference/api/search/uri-request.html>
+The I<lite> L<version of search|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/search-uri-request.html>
 allows you to specify a query string in the C<q> parameter, using the
 Lucene query string syntax:
 
     $results = $e->search( q => 'title:(elasticsearch clients)');
 
 However, the preferred way to search is by using the
-L<Query DSL|http://www.elasticsearch.org/guide/reference/query-dsl/>
+L<Query DSL|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/query-dsl.html>
 to create a query, and passing that C<query> in the
-L<request body|http://www.elasticsearch.org/guide/reference/api/search/request-body/>:
+L<request body|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/search-request-body.html>:
 
     $results = $e->search(
         body => {
@@ -719,7 +719,7 @@ Query string parameters:
     C<timeout>,
     C<version>
 
-See the L<search reference|http://www.elasticsearch.org/guide/reference/api/search/request-body/>
+See the L<search reference|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/search-request-body.html>
 for more information.
 
 =head2 C<count()>
@@ -731,7 +731,7 @@ for more information.
         body    => { query }                # optional
     )
 
-The C<count()> method returns just the total count of all documents matching the
+The C<count()> method returns the total count of all documents matching the
 query:
 
     $results = $e->count(
@@ -745,7 +745,7 @@ Query string parameters:
     C<routing>,
     C<source>
 
-See the L<count docs|http://www.elasticsearch.org/guide/reference/api/count/>
+See the L<count docs|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/search-count.html>
 for more information.
 
 =head2 C<scroll()>
@@ -771,8 +771,8 @@ Query string parameters:
     C<scroll>,
     C<scroll_id>
 
-See the L<scroll docs|http://www.elasticsearch.org/guide/reference/api/search/scroll/>
-and the L<search_type docs|http://www.elasticsearch.org/guide/reference/api/search/search-type/>
+See the L<scroll docs|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/search-request-scroll.html>
+and the L<search_type docs|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/search.html/search-request-search-type.html>
 for more information.
 
 =head2 C<clear_scroll()>
@@ -816,7 +816,7 @@ request).  For instance:
 Query string parameters:
     C<search_type>
 
-See the L<msearch docs|http://www.elasticsearch.org/guide/reference/api/multi-search/>
+See the L<msearch docs|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/search-multi-search.html>
 for more information.
 
 =head2 C<explain()>
@@ -861,7 +861,7 @@ Query string parameters:
     C<routing>,
     C<source>
 
-See the L<explain docs|http://www.elasticsearch.org/guide/reference/api/explain/>
+See the L<explain docs|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/search-explain.html>
 for more information.
 
 =head2 C<percolate()>
@@ -894,7 +894,7 @@ C<_source> field of the document under the C<doc> key:
 Query string parameters:
     C<prefer_local>
 
-See the L<percolate docs|http://www.elasticsearch.org/guide/reference/api/percolate/>
+See the L<percolate docs|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/search-percolate.html>
 for more information.
 
 =head2 C<suggest()>
@@ -907,8 +907,8 @@ for more information.
     );
 
 The C<suggest()> method is used to run
-L<did-you-mean|http://www.elasticsearch.org/guide/reference/api/search/phrase-suggest/>
-or L<search-as-you-type|http://www.elasticsearch.org/guide/reference/api/search/completion-suggest.html>
+L<did-you-mean|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/search-suggesteres-phrase.html>
+or L<search-as-you-type|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/search-suggesters-completion.html>
 suggestion requests, which can also be run as part of a L</search()> request.
 
     $results = $e->suggest(
@@ -941,7 +941,7 @@ Query string parameters:
     );
 
 The C<mlt()> method runs a
-L<more-like-this query|http://www.elasticsearch.org/guide/reference/query-dsl/mlt-query/>
+L<more-like-this query|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/query-dsl-mlt-query.html>
 to find other documents which are similar to the specified document.
 
 Query string parameters:
@@ -965,7 +965,7 @@ Query string parameters:
     C<search_types>,
     C<stop_words>
 
-See the L<mlt docs|http://www.elasticsearch.org/guide/reference/api/more-like-this/>
+See the L<mlt docs|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/search-more-like-this.html>
 for more information.
 
 =head1 AUTHOR
