@@ -1,7 +1,7 @@
 #===================================
 package Elasticsearch::Client::Direct::Cluster;
 {
-  $Elasticsearch::Client::Direct::Cluster::VERSION = '0.73';
+  $Elasticsearch::Client::Direct::Cluster::VERSION = '0.74';
 }
 #===================================
 use Moo;
@@ -19,7 +19,7 @@ Elasticsearch::Client::Direct::Cluster - A client for running cluster-level requ
 
 =head1 VERSION
 
-version 0.73
+version 0.74
 
 =head1 DESCRIPTION
 
@@ -49,7 +49,7 @@ Query string parameters:
     C<wait_for_relocating_shards>,
     C<wait_for_status>
 
-See the L<cluster health docs|http://www.elasticsearch.org/guide/reference/api/admin-cluster-health/>
+See the L<cluster health docs|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/cluster-health.html>
 for more information.
 
 =head2 C<node_info()>
@@ -76,7 +76,7 @@ Query string parameters:
     C<timeout>,
     C<transport>
 
-See the L<node_info docs|http://www.elasticsearch.org/guide/reference/api/admin-cluster-nodes-info/>
+See the L<node_info docs|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/cluster-nodes-info.html>
 for more information.
 
 =head2 C<node_stats()>
@@ -115,7 +115,7 @@ Query string parameters:
     C<thread_pool>,
     C<transport>
 
-See the L<node_stats docs|http://www.elasticsearch.org/guide/reference/api/admin-cluster-nodes-stats/>
+See the L<node_stats docs|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/cluster-nodes-stats.html>
 for more information.
 
 =head2 C<hot_threads()>
@@ -133,7 +133,7 @@ Query string parameters:
     C<threads>,
     C<type>
 
-See the L<hot_threads docs|http://www.elasticsearch.org/guide/reference/api/admin-cluster-nodes-hot-threads/>
+See the L<hot_threads docs|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/cluster-nodes-hot-threads.html>
 for more information.
 
 =head2 C<get_settings()>
@@ -143,7 +143,7 @@ for more information.
 The C<get_settings()> method is used to retrieve cluster-wide settings that
 have been set with the L</put_settings()> method.
 
-See the L<cluster settings docs|http://www.elasticsearch.org/guide/reference/api/admin-cluster-update-settings/>
+See the L<cluster settings docs|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/cluster-update-settings.html>
 for more information.
 
 =head2 C<put_settings()>
@@ -162,7 +162,7 @@ For instance:
         }
     );
 
-See the L<cluster settings docs|http://www.elasticsearch.org/guide/reference/api/admin-cluster-update-settings/>
+See the L<cluster settings docs|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/cluster-update-settings.html>
  for more information.
 
 =head2 C<state()>
@@ -182,7 +182,7 @@ Query string parameters:
     C<local>,
     C<master_timeout>
 
-See the L<cluster state docs|http://www.elasticsearch.org/guide/reference/api/admin-cluster-state/>
+See the L<cluster state docs|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/cluster-state.html>
 for more information.
 
 =head2 C<reroute()>
@@ -217,7 +217,7 @@ Query string parameters:
     C<dry_run>,
     C<filter_metadata>
 
-See the L<reroute docs|http://www.elasticsearch.org/guide/reference/api/admin-cluster-reroute/>
+See the L<reroute docs|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/cluster-reroute.html>
 for more information.
 
 =head2 C<shutdown()>
@@ -233,7 +233,7 @@ Query string parameters:
     C<delay>,
     C<exit>
 
-See the L<shutdown docs|http://www.elasticsearch.org/guide/reference/api/admin-cluster-nodes-shutdown/>
+See the L<shutdown docs|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/cluster-nodes-shutdown.html>
 for more information.
 
 =head1 AUTHOR
